@@ -17,7 +17,7 @@ from base64 import b64encode
 # importa re per fare le regular espression che effettuano i cambiamenti nel xml
 import re
 
-import pyTools as pyTools
+import rsi_python_lib.pyTools as pyTools
 
 # debug setting
 http_handler = urllib.request.HTTPHandler(debuglevel=1)
