@@ -17,11 +17,11 @@ import boto3
 #SECRET_KEY = '/nGXeFNLmCIOd6oZNyOaTuH5umU9mYrR+ZtOIjrY'
 #BUCKET_NAME = 'rsiori-prd'
 
-import pyCueServices as cueServices
-import xmlService as xmlService
-import pyCueContenType as CCType
-import pyConfig as pyConfig
-import pySettaVars as pySettaVars
+import rsi_python_lib.pyCueServices as cueServices
+import rsi_python_lib.xmlService as xmlService
+import rsi_python_lib.pyCueContenType as CCType
+import rsi_python_lib.pyConfig as pyConfig
+import rsi_python_lib.pySettaVars as pySettaVars
 
 logger = logging.getLogger('pyTools')
 
